@@ -11,9 +11,16 @@
 #' out = spscan.test(grave, nsim = 99)
 #' # print scan object
 #' clusters(out)
-clusters = function(x) {
-  if (!is.element("spscan", class(x))) {
-    stop("x must have spscan class")
+#' @method clusters spscan
+#' @inheritParams smerc::clusters
+#' @export
+clusters.spscan = function(x, idx = seq_along(x$clusters), ...) {
+  if (min(idx) < 1 | max(idx) > length(x$clusters)) {
+    stop("invalid idx values")
   }
-  smerc::lget(x$clusters, "locids")
-}
\ No newline at end of file
+  smerc::lget(x$clusters[idx], "locids")
+}
+
+#' @importFrom smerc clusters
+#' @export
+smerc::clusters
\ No newline at end of file
